/**
 * @typedef {object} ReactionEntry
 * @property {string} label
 * @property {string} rxnCode
 */
/**
 * Create reaction trees of products based on reactions and reactants
 * @param {import('openchemlib').Molecule[]} reactants
 * @param {ReactionEntry[]} reactions - array of reactions objects with rxnCode, label
 * @param {object} options - options to apply the reaction
 * @param {number} [options.maxDepth=5] - max depth of the recursion
 * @param {number} [options.limitReactions=200] - limit the number of reactions to apply
 * @param {boolean} [options.getProductsTrees=false] - if true, the returned object will have a products property with the products trees grouped by idCode else it will be an empty array
 * @returns {object} The returned object has two properties:
 * - trees: the tree of reactions
 * - products: reactions trees grouped by product idCode
 */
export function applyReactions(reactants: import("openchemlib").Molecule[], reactions: ReactionEntry[], options?: {
    maxDepth?: number | undefined;
    limitReactions?: number | undefined;
    getProductsTrees?: boolean | undefined;
}): object;
export type ReactionEntry = {
    label: string;
    rxnCode: string;
};
//# sourceMappingURL=applyReactions.d.ts.map